@@ -12,9 +12,8 @@ import time
 from datetime import datetime, timedelta
 from typing import Optional, Union, Dict, Any, List, Type, cast, Sequence
 
-from requests import Response
-
 from bigbuy.rate_limit import RateLimit
+from requests import Response
 
 
 class BBError(Exception):
@@ -39,14 +38,6 @@ class BBRateLimitError(BBResponseError):
         super().__init__(text, response)
         self.rate_limit = RateLimit.from_response(response)
 
-    # backward compatibility
-    @property
-    def reset_time(self):
-        if self.rate_limit is not None:
-            return self.rate_limit.reset_time
-
-        return None
-
     # backward compatibility
     def reset_timedelta(self, utcnow: Optional[datetime] = None):
         if self.rate_limit is not None:
@@ -128,10 +119,6 @@ class BBWarehouseSplitError(BBShippingError):
         self.warehouses = warehouses
 
 
-# Backward compatibility
-BBWarehouseError = BBWarehouseSplitError
-
-
 class BBInvalidPaymentError(BBResponseError):
     pass
 
@@ -154,6 +141,10 @@ class BBServerError(BBResponseError):
     pass
 
 
+class BBTimeoutError(BBServerError, TimeoutError):
+    pass
+
+
 class BBValidationError(BBResponseError):
     def __init__(self, error_fields, response: Response, **kwargs):
         text = "Validation failed: %s" % str(error_fields)
@@ -260,7 +251,7 @@ def raise_for_response(response: Response):
     Equivalent of request.Response#raise_for_status() that raises an exception based on the response's status.
     This may modify its argument to fix the status code if the response is a soft error.
     """
-    text = response.text
+    text = response.text.strip()
     content = json_or_none(text)
 
     # BigBuy may return soft errors (with a '200 OK' code)
@@ -293,31 +284,45 @@ def raise_for_response(response: Response):
     if content is None:
         if text == "You exceeded the rate limit":
             error_class: Type[BBResponseError] = BBRateLimitError
-        elif is_5xx or \
-                text.startswith("<html><body><h1>504 Gateway Time-out</h1>") or \
-                "Internal Server Error" in text or \
-                text == "Bad Gateway":
+
+        elif (
+                "<h1>504 Gateway Time-out</h1>" in text
+                or "504 Gateway Time-out" in text
+                or "503 Service Unavailable" in text
+                or "No server is available to handle this request." in text
+                or "The server didn't respond in time." in text
+                or text.startswith('Idle timeout reached for')
+                # (yes, there is a double space)
+                or text.startswith('HTTP/2 503  returned for "https://www.bigbuy.eu/order/payment/')
+        ):
+            error_class = BBTimeoutError
+        elif is_5xx or text == "Bad Gateway" or "Internal Server Error" in text:
             error_class = BBServerError
         else:
             error_class = BBResponseError
 
         # Trim what we can.
         if text.startswith("<html>") or text.startswith("<!DOCTYPE html>"):
-            # We may want to go further:
-            #   '<div class="container">
-            #       <h1>Oops! An Error Occurred</h1>
-            #       <h2>The server returned a "500 Internal Server Error".</h2>
-            #
-            #       <p>
-            #           Something is broken. Please let us know what you were doing when this error occurred.
-            #           We will fix it as soon as possible. Sorry for any inconvenience caused.
-            #       </p>
-            #   </div>'
-            if m := re.match(r".+<body>(.+)</body>\s*</html>\s*", text, re.DOTALL):
+            if m := re.match(r".+<body>(.+)</body>", text, re.DOTALL):
                 text = m.group(1).strip()
 
-                # Trim "<h1>504 Gateway Time-out</h1>"
-                if m := re.match(r"<h1>5\d\d .+?</h1>(.+)$", text, re.DOTALL):
+                # <div class="container">
+                #    <h1>Oops! An Error Occurred</h1>
+                #    <h2>The server returned a "500 Internal Server Error".</h2>
+                #    <p>
+                #        Something is broken. Please let us know what you were doing when this error occurred.
+                #        We will fix it as soon as possible. Sorry for any inconvenience caused.
+                #    </p>
+                # </div>
+                if m := re.match(r'<div class="container">(.+)</div>', text, re.DOTALL):
+                    text = m.group(1).strip()
+
+                text = text.replace("<h1>Oops! An Error Occurred</h1>", "").strip()
+
+                if m := re.match(r'<h2>The server returned a "500 Internal Server Error".</h2>\s*'
+                                 r'<p>(.+)</p>$', text, re.DOTALL):
+                    text = m.group(1).strip()
+                elif m := re.match(r'<h1>5.. .*?</h1>\s*(.+)', text, re.DOTALL):
                     text = m.group(1).strip()
 
         raise error_class(text, response)
@@ -364,6 +369,10 @@ def raise_for_response(response: Response):
         bb_code = content["code"]
         message = content["message"]
 
+        # {"code": "Bad request", "message": 400}
+        if isinstance(message, int) and 400 <= message <= 599 and isinstance(bb_code, str):
+            bb_code, message = str(message), bb_code
+
     if "error_detail" in content and "different warehouses" in message:
         error_detail = content["error_detail"]
         if isinstance(error_detail, dict) and "warehouses" in error_detail:
@@ -403,11 +412,3 @@ def raise_for_response(response: Response):
             raise BBProductError(text, response, bb_code, bb_data, skus=skus)
 
     raise error_class(text, response, bb_code=bb_code, bb_data=bb_data)
-
-
-# deprecated
-def wait_rate_limit(e: BBRateLimitError, wait_function=time.sleep, additional_delay=0.01):
-    if not isinstance(e, BBRateLimitError):
-        return False
-
-    return e.wait_until_expiration(wait_function=wait_function, additional_delay=additional_delay)
